@@ -1,5 +1,3 @@
-# flake8: noqa
-
 """Controllers for miscellaneous devices.
 
 Controller may refer to collection of functions to control devices or implementation of
@@ -7,4 +5,4 @@ some algorithms to control something.
 
 """
 
-from .antenna_pid import *
+from .antenna_pid import *  # noqa: F401, F403
