@@ -6,11 +6,12 @@ from typing import Callable, Generator, List, Optional, Tuple, TypeVar, Union
 
 import astropy.units as u
 import numpy as np
-from astropy.coordinates import BaseCoordinateFrame, SkyCoord, get_body
+from astropy.coordinates import SkyCoord, get_body
+from astropy.coordinates.name_resolve import NameResolveError
 from astropy.time import Time
 
 from .. import config, utils
-from ..typing import Number, UnitType
+from ..typing import CoordFrameType, Number, UnitType
 from .convert import CoordCalculator
 
 T = TypeVar("T", Number, u.Quantity)
@@ -74,7 +75,7 @@ class Timer:
         self.start = pytime.time()
         self.target = self.start
 
-    def set_offset(self, /, offset) -> None:
+    def set_offset(self, offset) -> None:
         if not isinstance(offset, (int, float)):
             raise TypeError(f"Offset must be int or float, not {type(offset)}")
         self.target += offset
@@ -144,7 +145,7 @@ class PathFinder(CoordCalculator):
         self,
         lon: Callable[[float], T],
         lat: Callable[[float], T],
-        frame: Union[str, BaseCoordinateFrame],
+        frame: CoordFrameType,
         *,
         unit: Optional[UnitType] = None,
         n_cmd: Union[int, float],
@@ -189,10 +190,9 @@ class PathFinder(CoordCalculator):
         [1610612736.0, 1610612736.1, 1610612736.2, ...])
 
         """
-        if time is None:
-            start = pytime.time() + config.antenna_command_offset_sec
-        else:
-            start = time.get() + config.antenna_command_offset_sec
+        time = time or Timer()
+        start = time.get() + config.antenna_command_offset_sec
+        time.set_offset(n_cmd / config.antenna_command_frequency)
 
         for seq in range(math.ceil(n_cmd / self.unit_n_cmd)):
             idx = [seq * self.unit_n_cmd + j for j in range(self.unit_n_cmd)]
@@ -221,7 +221,7 @@ class PathFinder(CoordCalculator):
         self,
         start: Tuple[T, T],
         end: Tuple[T, T],
-        frame: Union[str, BaseCoordinateFrame],
+        frame: CoordFrameType,
         *,
         speed: Union[float, int, u.Quantity],
         unit: Optional[UnitType] = None,
@@ -276,11 +276,11 @@ class PathFinder(CoordCalculator):
             lon, lat, frame, unit=unit, n_cmd=float(n_cmd), time=time
         )
 
-    def linear_with_acceleration(
+    def accelerate_to(
         self,
         start: Tuple[T, T],
         end: Tuple[T, T],
-        frame: Union[str, BaseCoordinateFrame],
+        frame: CoordFrameType,
         *,
         speed: Union[float, int, u.Quantity],
         unit: Optional[UnitType] = None,
@@ -319,7 +319,22 @@ class PathFinder(CoordCalculator):
 
         time = time or Timer()
         yield from self.functional(lon, lat, frame, unit=unit, n_cmd=n_cmd, time=time)
-        time.set_offset(required_time.to_value("s"))
+
+    def linear_with_acceleration(
+        self,
+        start: Tuple[T, T],
+        end: Tuple[T, T],
+        frame: CoordFrameType,
+        *,
+        speed: Union[float, int, u.Quantity],
+        unit: Optional[UnitType] = None,
+        margin: Union[float, int, u.Quantity],
+        time: Optional[Timer] = None,
+    ) -> Generator[Tuple[u.Quantity, u.Quantity, List[float]], None, None]:
+        time = time or Timer()
+        yield from self.accelerate_to(
+            start, end, frame, speed=speed, unit=unit, margin=margin, time=time
+        )
         yield from self.linear(start, end, frame, speed=speed, unit=unit, time=time)
 
     def offset_linear(
@@ -330,6 +345,11 @@ class PathFinder(CoordCalculator):
 
     def offset_track(
         self,
+        lon: T,
+        lat: T,
+        frame: CoordFrameType,
+        *,
+        unit: Optional[UnitType] = None,
     ) -> Generator[Tuple[u.Quantity, u.Quantity, List[float]], None, None]:
         ...
         raise NotImplementedError
@@ -338,7 +358,7 @@ class PathFinder(CoordCalculator):
         self,
         lon: T,
         lat: T,
-        frame: Union[str, BaseCoordinateFrame],
+        frame: CoordFrameType,
         *,
         unit: Optional[UnitType] = None,
         time: Optional[Timer] = None,
@@ -353,7 +373,6 @@ class PathFinder(CoordCalculator):
                 n_cmd=self.unit_n_cmd,
                 time=time,
             )
-            time.set_offset(self.command_unit_duration_sec)
 
     def track_by_name(
         self, name: str, *, time: Optional[Timer] = None
@@ -363,10 +382,9 @@ class PathFinder(CoordCalculator):
         def get_coord(name: str, t: List[float]):
             t = Time(t, format="unix")
             try:
-                coord = get_body(name, t, self.location)
+                return get_body(name, t, self.location)
             except KeyError:
-                coord = SkyCoord.from_name(name)
-            return coord
+                return SkyCoord.from_name(name)
 
         idx = [i / (self.unit_n_cmd - 1) for i in range(self.unit_n_cmd)]
         while True:
@@ -375,15 +393,22 @@ class PathFinder(CoordCalculator):
                 start_time + (i / config.antenna_command_frequency)
                 for i in range(self.unit_n_cmd)
             ]
-            coord = get_coord(name, t)
+            try:
+                coord = get_coord(name, t)
+            except NameResolveError:
+                self.logger.error(f"Cannot resolve {name!r}")
+                return f"Cannot resolve {name!r}"
 
             def lon(x):
+                if coord.ra.size == 1:
+                    return coord.ra
                 return np.interp(x, idx, coord.ra)
 
             def lat(x):
+                if coord.dec.size == 1:
+                    return coord.dec
                 return np.interp(x, idx, coord.dec)
 
             yield from self.functional(
                 lon, lat, coord.frame.name, n_cmd=self.unit_n_cmd, time=time
             )
-            time.set_offset(self.command_unit_duration_sec)
