@@ -1,9 +1,19 @@
 from abc import ABC, abstractmethod
 from pathlib import Path
-from typing import Any
+from typing import Any, Dict, Type
 
 
 class Writer(ABC):
+
+    _instance: Dict[Type["Writer"], "Writer"] = {}
+    _initialized: Dict[Type["Writer"], bool] = {}
+
+    def __new__(cls, *args, **kwargs):
+        if cls._instance.get(cls) is None:
+            cls._instance[cls] = super().__new__(cls)
+            cls._initialized[cls] = False
+        return cls._instance[cls]
+
     @abstractmethod
     def start_recording(self, record_dir: Path) -> None:
         ...
